Struct GridConfig
pub struct GridConfig { /* private fields */ }Expand description
Write-access helper for the scene grid configuration.
Implementations
impl GridConfig
impl GridConfig
pub fn enabled(&self, value: bool) -> Instruction
pub fn enabled(&self, value: bool) -> Instruction
Sets whether the grid is enabled.
pub fn size(&self, value: f64) -> Instruction
pub fn size(&self, value: f64) -> Instruction
Sets the number of grid divisions.
pub fn infinite_grid(&self, value: bool) -> Instruction
pub fn infinite_grid(&self, value: bool) -> Instruction
Sets whether the grid extends infinitely.
pub fn fade_distance(&self, value: f64) -> Instruction
pub fn fade_distance(&self, value: f64) -> Instruction
Sets the distance at which the grid starts to fade.
pub fn fade_strength(&self, value: f64) -> Instruction
pub fn fade_strength(&self, value: f64) -> Instruction
Sets the strength of the grid fade effect.
pub fn cell_size(&self, value: f64) -> Instruction
pub fn cell_size(&self, value: f64) -> Instruction
Sets the size of each cell in the grid.
pub fn cell_color(&self, value: &str) -> Instruction
pub fn cell_color(&self, value: &str) -> Instruction
Sets the color of the grid cells.
pub fn cell_thickness(&self, value: f64) -> Instruction
pub fn cell_thickness(&self, value: f64) -> Instruction
Sets the thickness of the grid cells.
pub fn section_size(&self, value: f64) -> Instruction
pub fn section_size(&self, value: f64) -> Instruction
Sets the size of each section in the grid.
pub fn section_color(&self, value: &str) -> Instruction
pub fn section_color(&self, value: &str) -> Instruction
Sets the color of the grid sections.
pub fn section_thickness(&self, value: f64) -> Instruction
pub fn section_thickness(&self, value: f64) -> Instruction
Sets the thickness of the grid sections.